"""Hutch - Security Engineering Toolkit."""

__version__ = "0.2.0"
__title__ = "hutch-security"
__author__ = "HashiCorp Security (Security Engineering)"
__license__ = "Mozilla Public License 2.0"
__copyright__ = "Copyright 2022 HashiCorp, Inc."



"""HashiCorp Security Engineering Toolkit."""

from hutch.security import annotation  # noqa: F401
from hutch.security import jupiterone  # noqa: F401
from hutch.security import parsers  # noqa: F401
from hutch.security import sumologic  # noqa: F401
from hutch.security import utilities  # noqa: F401
from hutch.security.__about__ import *  # noqa: F401, F403



#!/usr/bin/env python3
"""Minimal setup for hutch-security."""
import os

from setuptools import setup

# setupmeta does not seem to pull in metadata from namespace packages. As a result, we
# need to pull things in ourselves.
__version__ = "0.0.0"
__author__ = "Not Defined"

path = os.path.dirname(os.path.abspath(__file__))
exec(open(os.path.join(path, "hutch/security/__about__.py")).read())  # noqa: S102

# Dependencies are defined here direclty, rather than via requirements.txt, as we do not
# want to version pin for a library used by multiple downstream projects - due to
# interoperatbility concerns.
setup(
    version=__version__,
    author=__author__,
    packages=["hutch.security"],
    install_requires=[
        "sumologic-sdk",
        "requests",
        "pydantic",
        "jmespath",
    ],
)
